angular.module('starter.services', [])

// 分类
.factory('Category', function ($resource, API_URI) {
    return $resource(API_URI + 'categorys');
})

// 商品
.factory('Goods', function ($resource, API_URI) {
    return $resource(API_URI + 'goods/list/:cid/:p', { cid: '@id', p: '@p' });
})

// 商品详情
.factory('GoodsDetail', function ($resource, API_URI) {
    return $resource(API_URI + 'goods/one', { goods_id: '@goods_id' });
})

// 热卖商品
.factory('GoodsHot', function ($resource, API_URI) {
    return $resource(API_URI + 'goods/hot', { number: '@number' });
})

// 新品上市
.factory('GoodsNew', function ($resource, API_URI) {
    return $resource(API_URI + 'goods/new', { number: '@number' });
})

// 精品热卖
.factory('GoodsBest', function ($resource, API_URI) {
    return $resource(API_URI + 'goods/best', { number: '@number' });
})


// 购物车
.factory('Cart', function ($resource, API_URI) {
    return $resource(API_URI + 'goods/cart/:device_id', { device_id: '@device_id' }, { save: { method: 'POST', isArray: false } });
})

// 用户
.factory('ProfileCounts', function ($resource, API_URI) {
    return $resource(API_URI + 'profileCounts', { token: '@token' });
})

// 订单
.factory('Orders', function ($resource, API_URI) {
    return $resource(API_URI + 'orders', { token: '@token' }, {
        query: {
            method: 'GET',
            isArray: false,
            params: {
                order_id: '@order_id'
            }
        },
        update: {
            method: 'PUT'
        },
        delete: {
            method: 'DELETE'
        },
        done: {
            method: 'POST'
        }
    });
})

// 确认订单
.factory('Checkout', function ($resource, API_URI) {
    return $resource(API_URI + 'checkout', { token: '@token' }, {
        get: {
            method: 'GET',
        },
        checkout: {
            method: 'POST'
        }
    })
})

// 支付
.factory('Pay', function ($resource, API_URI) {
    return $resource(API_URI + 'pay', { token: '@token' }, {
        get: {
            method: 'GET',
        },
        done: {
            method: 'POST'
        }
    })
})

// 收藏夹
.factory('Collect', function ($resource, API_URI) {
    return $resource(API_URI + 'collect', { token: '@token' }, {
        get: {
            method: 'GET',
        },
        post: {
            method: 'POST',
        },
        delete: {
            method: 'DELETE',
        }
    })
})

// 短信验证码
.factory('SmsCode', function ($resource, API_URI) {
    return $resource(API_URI + 'sms_code', { phone: '@phone' });
})

// 优惠券
.factory('Coupon', function ($resource, API_URI) {
    return $resource(API_URI + 'coupon', { token: '@token' }, {
        get: {
            method: 'GET',
        },
        add: {
            method: 'POST'
        }
    });
})

// 头像
.factory('Avatar', function ($resource, API_URI) {
    return $resource(API_URI + 'avatar', {}, {
        post: {
            method: 'POST'
        }
    })
})

// 搜索
.factory('Search', function ($resource, API_URI) {
    return $resource(API_URI + 'search', { k: '@k' }, {
        query: {
            method: 'get',
            isArray: true
        }
    });
})

// 用户
.factory('User', function ($rootScope, $resource, API_URI) {
    return $resource(API_URI + 'user', { token: '@token' }, {
        query: {
            method: 'GET',
            isArray: false
        },
        login: {
            method: 'GET',
            isArray: false
        },
        save: {
            method: 'PUT'
        },
        register: {
            method: 'POST'
        }
    })
})

// 收货地址
.factory('Address', function ($resource, API_URI) {
    return $resource(API_URI + 'address', {
        token: '@token'
    }, {
        add: {
            method: 'POST',
        },
        edit: {
            method: 'PUT'
        },
        delete: {
            method: 'DELETE'
        }
    })
})

// 地址区域
.factory('Region', function ($resource, API_URI) {
    return $resource(API_URI + 'region', { pid: '@pid' });
})

// 系统配置
.factory('SystemConfig', function ($resource, API_URI) {
    return $resource(API_URI + 'configs', {});
})

// 文章
.factory('Articles', function ($resource, API_URI) {
    return $resource(API_URI + 'articles', {});
})

// 广告
.factory('Ads', function ($resource, API_URI) {
    return $resource(API_URI + 'ad');
})

// 本地存储服务
.factory('locals', ['$window', function ($window) {
    return { //存储单个属性
        set: function (key, value) {
            $window.localStorage[key] = value;
        }, //读取单个属性
        get: function (key, defaultValue) {
            return $window.localStorage[key] || defaultValue;
        }, //存储对象，以JSON格式存储
        setObject: function (key, value) {
            $window.localStorage[key] = JSON.stringify(value);
        }, //读取对象
        getObject: function (key) {
            return JSON.parse($window.localStorage[key] || '{}');
        }

    }
}])

// 促销专区
.factory('Activity', function ($resource, API_URI) {
    return $resource(API_URI + 'activity', {});
})

// 专题
.factory('Topic', function ($resource, API_URI) {
    return $resource(API_URI + 'topic', {});
})

// 图像地址过滤器
.filter('serimg', function (STATIC_URI) {
    return function (url) {
        if (url == '' || url == undefined) {
            return './img/ionic.png';
        } else {
            return STATIC_URI + url;
        }
    }
})

// 头像地址过滤器
.filter('avatar', function () {
    return function (url) {
        if (url == '' || url == undefined) {
            return './img/ionic.png';
        } else {
            return 'data:image/jpeg;base64,' + url;
        }
    }
})
